@@ -11,19 +11,30 @@
 
 // *** THIS FILE CANNOT TAKE ANY LLVM DEPENDENCIES  *** //
 
-#include <string>
-#include <sstream>
-#include <fstream>
+#include <algorithm>
 #include <atomic>
 #include <cmath>
+#include <fstream>
+#include <sstream>
+#include <string>
 #include <vector>
-#include <algorithm>
 #ifdef _WIN32
-#include <dxgiformat.h>
+
+// Disable -Wignored-qualifiers for WexTestClass.h.
+// For const size_t GetSize() const; in TestData.h.
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wignored-qualifiers"
+#endif
 #include "WexTestClass.h"
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+
+#include <dxgiformat.h>
 #else
-#include "dxc/Support/Global.h" // DXASSERT_LOCALVAR
 #include "WEXAdapter.h"
+#include "dxc/Support/Global.h" // DXASSERT_LOCALVAR
 #endif
 #include "dxc/DXIL/DxilConstants.h" // DenormMode
 
@@ -61,22 +72,33 @@ using namespace std;
 #endif
 #define EXPECT_STREQW(a, b) VERIFY_ARE_EQUAL(0, wcscmp(a, b))
 #define VERIFY_ARE_EQUAL_CMP(a, b, ...) VERIFY_IS_TRUE(a == b, __VA_ARGS__)
-#define VERIFY_ARE_EQUAL_STR(a, b) { \
-  const char *pTmpA = (a);\
-  const char *pTmpB = (b);\
-  if (0 != strcmp(pTmpA, pTmpB)) {\
-    CA2W conv(pTmpB, CP_UTF8); WEX::Logging::Log::Comment(conv);\
-    const char *pA = pTmpA; const char *pB = pTmpB; \
-    while(*pA == *pB) { pA++; pB++; } \
-    wchar_t diffMsg[32]; swprintf_s(diffMsg, _countof(diffMsg), L"diff at %u", (unsigned)(pA-pTmpA)); \
-    WEX::Logging::Log::Comment(diffMsg); \
-  } \
-  VERIFY_ARE_EQUAL(0, strcmp(pTmpA, pTmpB)); \
-}
-#define VERIFY_ARE_EQUAL_WSTR(a, b) { \
-  if (0 != wcscmp(a, b)) { WEX::Logging::Log::Comment(b);} \
-  VERIFY_ARE_EQUAL(0, wcscmp(a, b)); \
-}
+#define VERIFY_ARE_EQUAL_STR(a, b)                                             \
+  {                                                                            \
+    const char *pTmpA = (a);                                                   \
+    const char *pTmpB = (b);                                                   \
+    if (0 != strcmp(pTmpA, pTmpB)) {                                           \
+      CA2W conv(pTmpB);                                                        \
+      WEX::Logging::Log::Comment(conv);                                        \
+      const char *pA = pTmpA;                                                  \
+      const char *pB = pTmpB;                                                  \
+      while (*pA == *pB) {                                                     \
+        pA++;                                                                  \
+        pB++;                                                                  \
+      }                                                                        \
+      wchar_t diffMsg[32];                                                     \
+      swprintf_s(diffMsg, _countof(diffMsg), L"diff at %u",                    \
+                 (unsigned)(pA - pTmpA));                                      \
+      WEX::Logging::Log::Comment(diffMsg);                                     \
+    }                                                                          \
+    VERIFY_ARE_EQUAL(0, strcmp(pTmpA, pTmpB));                                 \
+  }
+#define VERIFY_ARE_EQUAL_WSTR(a, b)                                            \
+  {                                                                            \
+    if (0 != wcscmp(a, b)) {                                                   \
+      WEX::Logging::Log::Comment(b);                                           \
+    }                                                                          \
+    VERIFY_ARE_EQUAL(0, wcscmp(a, b));                                         \
+  }
 #ifndef ASSERT_EQ
 #define ASSERT_EQ(expected, actual) VERIFY_ARE_EQUAL(expected, actual)
 #endif
@@ -89,10 +111,11 @@ using namespace std;
 #define ASSERT_HRESULT_SUCCEEDED VERIFY_SUCCEEDED
 #ifndef EXPECT_EQ
 #define EXPECT_EQ(expected, actual) VERIFY_ARE_EQUAL(expected, actual)
-#endif 
+#endif
 #endif // VERIFY_ARE_EQUAL
 
 static constexpr char whitespaceChars[] = " \t\r\n";
+static constexpr wchar_t wideWhitespaceChars[] = L" \t\r\n";
 
 inline std::string strltrim(const std::string &value) {
   size_t first = value.find_first_not_of(whitespaceChars);
@@ -108,31 +131,58 @@ inline std::string strtrim(const std::string &value) {
   return strltrim(strrtrim(value));
 }
 
-inline bool strstartswith(const std::string& value, const char* pattern) {
-  for (size_t i = 0; ; ++i) {
-    if (pattern[i] == '\0') return true;
-    if (i == value.size() || value[i] != pattern[i]) return false;
+inline bool strstartswith(const std::string &value, const char *pattern) {
+  for (size_t i = 0;; ++i) {
+    if (pattern[i] == '\0')
+      return true;
+    if (i == value.size() || value[i] != pattern[i])
+      return false;
   }
 }
 
-inline std::vector<std::string> strtok(const std::string &value, const char *delimiters = whitespaceChars) {
+inline std::vector<std::string>
+strtok(const std::string &value, const char *delimiters = whitespaceChars) {
   size_t searchOffset = 0;
   std::vector<std::string> tokens;
   while (searchOffset != value.size()) {
     size_t tokenStartIndex = value.find_first_not_of(delimiters, searchOffset);
-    if (tokenStartIndex == std::string::npos) break;
+    if (tokenStartIndex == std::string::npos)
+      break;
     size_t tokenEndIndex = value.find_first_of(delimiters, tokenStartIndex);
-    if (tokenEndIndex == std::string::npos) tokenEndIndex = value.size();
-    tokens.emplace_back(value.substr(tokenStartIndex, tokenEndIndex - tokenStartIndex));
+    if (tokenEndIndex == std::string::npos)
+      tokenEndIndex = value.size();
+    tokens.emplace_back(
+        value.substr(tokenStartIndex, tokenEndIndex - tokenStartIndex));
     searchOffset = tokenEndIndex;
   }
   return tokens;
 }
 
-// strreplace will replace all instances of lookFors with replacements at the same index.
-// Will log an error if the string is not found, unless the first character is ? marking it optional.
-inline void strreplace(const std::vector<std::string>& lookFors, const std::vector<std::string>& replacements,
-                       std::string& str) {
+inline std::vector<std::wstring>
+strtok(const std::wstring &value,
+       const wchar_t *delimiters = wideWhitespaceChars) {
+  size_t searchOffset = 0;
+  std::vector<std::wstring> tokens;
+  while (searchOffset != value.size()) {
+    size_t tokenStartIndex = value.find_first_not_of(delimiters, searchOffset);
+    if (tokenStartIndex == std::string::npos)
+      break;
+    size_t tokenEndIndex = value.find_first_of(delimiters, tokenStartIndex);
+    if (tokenEndIndex == std::string::npos)
+      tokenEndIndex = value.size();
+    tokens.emplace_back(
+        value.substr(tokenStartIndex, tokenEndIndex - tokenStartIndex));
+    searchOffset = tokenEndIndex;
+  }
+  return tokens;
+}
+
+// strreplace will replace all instances of lookFors with replacements at the
+// same index. Will log an error if the string is not found, unless the first
+// character is ? marking it optional.
+inline void strreplace(const std::vector<std::string> &lookFors,
+                       const std::vector<std::string> &replacements,
+                       std::string &str) {
   for (unsigned i = 0; i < lookFors.size(); ++i) {
     bool bOptional = false;
     bool found = false;
@@ -158,8 +208,8 @@ inline void strreplace(const std::vector<std::string>& lookFors, const std::vect
     if (!bOptional) {
       if (!found) {
         WEX::Logging::Log::Comment(WEX::Common::String().Format(
-          L"String not found: '%S' in text:\r\n%.*S", pLookFor,
-          (unsigned)str.size(), str.data()));
+            L"String not found: '%S' in text:\r\n%.*S", pLookFor,
+            (unsigned)str.size(), str.data()));
       }
       VERIFY_IS_TRUE(found);
     }
@@ -168,8 +218,7 @@ inline void strreplace(const std::vector<std::string>& lookFors, const std::vect
 
 namespace hlsl_test {
 
-inline std::wstring
-vFormatToWString(_In_z_ _Printf_format_string_ const wchar_t *fmt, va_list argptr) {
+inline std::wstring vFormatToWString(const wchar_t *fmt, va_list argptr) {
   std::wstring result;
 #ifdef _WIN32
   int len = _vscwprintf(fmt, argptr);
@@ -185,8 +234,7 @@ vFormatToWString(_In_z_ _Printf_format_string_ const wchar_t *fmt, va_list argpt
   return result;
 }
 
-inline std::wstring
-FormatToWString(_In_z_ _Printf_format_string_ const wchar_t *fmt, ...) {
+inline std::wstring FormatToWString(const wchar_t *fmt, ...) {
   va_list args;
   va_start(args, fmt);
   std::wstring result(vFormatToWString(fmt, args));
@@ -194,7 +242,7 @@ FormatToWString(_In_z_ _Printf_format_string_ const wchar_t *fmt, ...) {
   return result;
 }
 
-inline void LogCommentFmt(_In_z_ _Printf_format_string_ const wchar_t *fmt, ...) {
+inline void LogCommentFmt(const wchar_t *fmt, ...) {
   va_list args;
   va_start(args, fmt);
   std::wstring buf(vFormatToWString(fmt, args));
@@ -202,30 +250,40 @@ inline void LogCommentFmt(_In_z_ _Printf_format_string_ const wchar_t *fmt, ...)
   WEX::Logging::Log::Comment(buf.data());
 }
 
-inline void LogErrorFmt(_In_z_ _Printf_format_string_ const wchar_t *fmt, ...) {
-    va_list args;
-    va_start(args, fmt);
-    std::wstring buf(vFormatToWString(fmt, args));
-    va_end(args);
-    WEX::Logging::Log::Error(buf.data());
+inline void LogErrorFmt(const wchar_t *fmt, ...) {
+  va_list args;
+  va_start(args, fmt);
+  std::wstring buf(vFormatToWString(fmt, args));
+  va_end(args);
+  WEX::Logging::Log::Error(buf.data());
 }
 
-inline std::wstring GetPathToHlslDataFile(const wchar_t* relative, LPCWSTR paramName = HLSLDATAFILEPARAM, LPCWSTR defaultDataDir = DEFAULT_TEST_DIR) {
-  WEX::TestExecution::SetVerifyOutput verifySettings(WEX::TestExecution::VerifyOutputSettings::LogOnlyFailures);
+inline std::wstring
+GetPathToHlslDataFile(const wchar_t *relative,
+                      LPCWSTR paramName = HLSLDATAFILEPARAM,
+                      LPCWSTR defaultDataDir = DEFAULT_TEST_DIR) {
+  WEX::TestExecution::SetVerifyOutput verifySettings(
+      WEX::TestExecution::VerifyOutputSettings::LogOnlyFailures);
   WEX::Common::String HlslDataDirValue;
   if (std::wstring(paramName).compare(HLSLDATAFILEPARAM) != 0) {
-    // Not fatal, for instance, FILECHECKDUMPDIRPARAM will dump files before running FileCheck, so they can be compared run to run
-    if (FAILED(WEX::TestExecution::RuntimeParameters::TryGetValue(paramName, HlslDataDirValue)))
+    // Not fatal, for instance, FILECHECKDUMPDIRPARAM will dump files before
+    // running FileCheck, so they can be compared run to run
+    if (FAILED(WEX::TestExecution::RuntimeParameters::TryGetValue(
+            paramName, HlslDataDirValue)))
       return std::wstring();
   } else {
-    if (FAILED(WEX::TestExecution::RuntimeParameters::TryGetValue(HLSLDATAFILEPARAM, HlslDataDirValue)))
+    if (FAILED(WEX::TestExecution::RuntimeParameters::TryGetValue(
+            HLSLDATAFILEPARAM, HlslDataDirValue)))
       HlslDataDirValue = defaultDataDir;
   }
 
   wchar_t envPath[MAX_PATH];
   wchar_t expanded[MAX_PATH];
-  swprintf_s(envPath, _countof(envPath), L"%ls\\%ls", reinterpret_cast<const wchar_t*>(HlslDataDirValue.GetBuffer()), relative);
-  VERIFY_WIN32_BOOL_SUCCEEDED(ExpandEnvironmentStringsW(envPath, expanded, _countof(expanded)));
+  swprintf_s(envPath, _countof(envPath), L"%ls\\%ls",
+             reinterpret_cast<const wchar_t *>(HlslDataDirValue.GetBuffer()),
+             relative);
+  VERIFY_WIN32_BOOL_SUCCEEDED(
+      ExpandEnvironmentStringsW(envPath, expanded, _countof(expanded)));
   return std::wstring(expanded);
 }
 
@@ -241,14 +299,13 @@ inline bool PathLooksAbsolute(LPCWSTR name) {
 static bool HasRunLine(std::string &line) {
   const char *delimiters = " ;/";
   auto lineelems = strtok(line, delimiters);
-  return !lineelems.empty() &&
-    lineelems.front().compare("RUN:") == 0;
+  return !lineelems.empty() && lineelems.front().compare("RUN:") == 0;
 }
 
 inline std::vector<std::string> GetRunLines(const LPCWSTR name) {
   const std::wstring path = PathLooksAbsolute(name)
-    ? std::wstring(name)
-    : hlsl_test::GetPathToHlslDataFile(name);
+                                ? std::wstring(name)
+                                : hlsl_test::GetPathToHlslDataFile(name);
 #ifdef _WIN32
   std::ifstream infile(path);
 #else
@@ -299,30 +356,37 @@ inline std::string GetFirstLine(LPCWSTR name) {
 }
 
 inline HANDLE CreateFileForReading(LPCWSTR path) {
-  HANDLE sourceHandle = CreateFileW(path, GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
+  HANDLE sourceHandle =
+      CreateFileW(path, GENERIC_READ, 0, 0, OPEN_EXISTING, 0, 0);
   if (sourceHandle == INVALID_HANDLE_VALUE) {
     DWORD err = GetLastError();
-    std::wstring errorMessage(FormatToWString(L"Unable to open file '%s', err=%u", path, err).c_str());
+    std::wstring errorMessage(
+        FormatToWString(L"Unable to open file '%s', err=%u", path, err)
+            .c_str());
     VERIFY_SUCCEEDED(HRESULT_FROM_WIN32(err), errorMessage.c_str());
   }
   return sourceHandle;
 }
 
 inline HANDLE CreateNewFileForReadWrite(LPCWSTR path) {
-  HANDLE sourceHandle = CreateFileW(path, GENERIC_READ | GENERIC_WRITE, 0, 0, CREATE_ALWAYS, 0, 0);
+  HANDLE sourceHandle = CreateFileW(path, GENERIC_READ | GENERIC_WRITE, 0, 0,
+                                    CREATE_ALWAYS, 0, 0);
   if (sourceHandle == INVALID_HANDLE_VALUE) {
     DWORD err = GetLastError();
-    std::wstring errorMessage(FormatToWString(L"Unable to create file '%s', err=%u", path, err).c_str());
+    std::wstring errorMessage(
+        FormatToWString(L"Unable to create file '%s', err=%u", path, err)
+            .c_str());
     VERIFY_SUCCEEDED(HRESULT_FROM_WIN32(err), errorMessage.c_str());
   }
   return sourceHandle;
 }
 
-// Copy of Unicode::IsStarMatchT/IsStarMatchWide is included here to avoid the dependency on
-// DXC support libraries.
-template<typename TChar>
-inline static
-bool IsStarMatchT(const TChar *pMask, size_t maskLen, const TChar *pName, size_t nameLen, TChar star) {
+// Copy of Unicode::IsStarMatchT/IsStarMatchWide is included here to avoid the
+// dependency on DXC support libraries.
+template <typename TChar>
+inline static bool IsStarMatchT(const TChar *pMask, size_t maskLen,
+                                const TChar *pName, size_t nameLen,
+                                TChar star) {
   if (maskLen == 0 && nameLen == 0) {
     return true;
   }
@@ -340,8 +404,7 @@ bool IsStarMatchT(const TChar *pMask, size_t maskLen, const TChar *pName, size_t
       return false;
     }
     return 0 == memcmp(pMask, pName, sizeof(TChar) * maskLen);
-  }
-  else {
+  } else {
     // Exact match.
     if (nameLen != maskLen) {
       return false;
@@ -350,7 +413,8 @@ bool IsStarMatchT(const TChar *pMask, size_t maskLen, const TChar *pName, size_t
   }
 }
 
-inline bool IsStarMatchWide(const wchar_t *pMask, size_t maskLen, const wchar_t *pName, size_t nameLen) {
+inline bool IsStarMatchWide(const wchar_t *pMask, size_t maskLen,
+                            const wchar_t *pName, size_t nameLen) {
   return IsStarMatchT<wchar_t>(pMask, maskLen, pName, nameLen, L'*');
 }
 
@@ -380,29 +444,30 @@ inline bool GetTestParamBool(LPCWSTR name) {
 inline bool GetTestParamUseWARP(bool defaultVal) {
   WEX::Common::String AdapterValue;
   if (FAILED(WEX::TestExecution::RuntimeParameters::TryGetValue(
-        L"Adapter", AdapterValue))) {
+          L"Adapter", AdapterValue))) {
     return defaultVal;
   }
   if ((defaultVal && AdapterValue.IsEmpty()) ||
-      AdapterValue.CompareNoCase(L"WARP") == 0) {
+      AdapterValue.CompareNoCase(L"WARP") == 0 ||
+      AdapterValue.CompareNoCase(L"Microsoft Basic Render Driver") == 0) {
     return true;
   }
   return false;
 }
 
-}
+} // namespace hlsl_test
 
 #ifdef FP_SUBNORMAL
 
-inline bool isdenorm(float f) {
-  return FP_SUBNORMAL == std::fpclassify(f);
-}
+inline bool isdenorm(float f) { return FP_SUBNORMAL == std::fpclassify(f); }
 
 #else
 
 inline bool isdenorm(float f) {
-  return (std::numeric_limits<float>::denorm_min() <= f && f < std::numeric_limits<float>::min()) ||
-         (-std::numeric_limits<float>::min() < f && f <= -std::numeric_limits<float>::denorm_min());
+  return (std::numeric_limits<float>::denorm_min() <= f &&
+          f < std::numeric_limits<float>::min()) ||
+         (-std::numeric_limits<float>::min() < f &&
+          f <= -std::numeric_limits<float>::denorm_min());
 }
 
 #endif // FP_SUBNORMAL
@@ -423,9 +488,7 @@ static const uint16_t Float16NegDenorm = 0x8008;
 static const uint16_t Float16PosZero = 0x0000;
 static const uint16_t Float16NegZero = 0x8000;
 
-inline bool GetSign(float x) {
-  return std::signbit(x);
-}
+inline bool GetSign(float x) { return std::signbit(x); }
 
 inline int GetMantissa(float x) {
   int bits = reinterpret_cast<int &>(x);
@@ -452,8 +515,9 @@ inline bool isnanFloat16(uint16_t val) {
 uint16_t ConvertFloat32ToFloat16(float val) throw();
 float ConvertFloat16ToFloat32(uint16_t val) throw();
 
-inline bool CompareFloatULP(const float &fsrc, const float &fref, int ULPTolerance,
-                            hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
+inline bool CompareFloatULP(
+    const float &fsrc, const float &fref, int ULPTolerance,
+    hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
   if (fsrc == fref) {
     return true;
   }
@@ -473,8 +537,9 @@ inline bool CompareFloatULP(const float &fsrc, const float &fref, int ULPToleran
   return uDiff <= (unsigned int)ULPTolerance;
 }
 
-inline bool CompareFloatEpsilon(const float &fsrc, const float &fref, float epsilon,
-                    hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
+inline bool CompareFloatEpsilon(
+    const float &fsrc, const float &fref, float epsilon,
+    hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
   if (fsrc == fref) {
     return true;
   }
@@ -493,12 +558,14 @@ inline bool CompareFloatEpsilon(const float &fsrc, const float &fref, float epsi
 }
 
 // Compare using relative error (relative error < 2^{nRelativeExp})
-inline bool CompareFloatRelativeEpsilon(const float &fsrc, const float &fref, int nRelativeExp,
-                            hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
+inline bool CompareFloatRelativeEpsilon(
+    const float &fsrc, const float &fref, int nRelativeExp,
+    hlsl::DXIL::Float32DenormMode mode = hlsl::DXIL::Float32DenormMode::Any) {
   return CompareFloatULP(fsrc, fref, 23 - nRelativeExp, mode);
 }
 
-inline bool CompareHalfULP(const uint16_t &fsrc, const uint16_t &fref, float ULPTolerance) {
+inline bool CompareHalfULP(const uint16_t &fsrc, const uint16_t &fref,
+                           float ULPTolerance) {
   if (fsrc == fref)
     return true;
   if (isnanFloat16(fsrc))
@@ -509,17 +576,19 @@ inline bool CompareHalfULP(const uint16_t &fsrc, const uint16_t &fref, float ULP
   return uDiff <= (unsigned int)ULPTolerance;
 }
 
-inline bool CompareHalfEpsilon(const uint16_t &fsrc, const uint16_t &fref, float epsilon) {
+inline bool CompareHalfEpsilon(const uint16_t &fsrc, const uint16_t &fref,
+                               float epsilon) {
   if (fsrc == fref)
     return true;
   if (isnanFloat16(fsrc))
     return isnanFloat16(fref);
   float src_f32 = ConvertFloat16ToFloat32(fsrc);
   float ref_f32 = ConvertFloat16ToFloat32(fref);
-  return std::abs(src_f32-ref_f32) < epsilon;
+  return std::abs(src_f32 - ref_f32) < epsilon;
 }
 
-inline bool CompareHalfRelativeEpsilon(const uint16_t &fsrc, const uint16_t &fref, int nRelativeExp) {
+inline bool CompareHalfRelativeEpsilon(const uint16_t &fsrc,
+                                       const uint16_t &fref, int nRelativeExp) {
   return CompareHalfULP(fsrc, fref, (float)(10 - nRelativeExp));
 }
 
@@ -527,76 +596,142 @@ inline bool CompareHalfRelativeEpsilon(const uint16_t &fsrc, const uint16_t &fre
 // returns the number of bytes per pixel for a given dxgi format
 // add more cases if different format needed to copy back resources
 inline UINT GetByteSizeForFormat(DXGI_FORMAT value) {
-    switch (value) {
-    case DXGI_FORMAT_R32G32B32A32_TYPELESS: return 16;
-    case DXGI_FORMAT_R32G32B32A32_FLOAT: return 16;
-    case DXGI_FORMAT_R32G32B32A32_UINT: return 16;
-    case DXGI_FORMAT_R32G32B32A32_SINT: return 16;
-    case DXGI_FORMAT_R32G32B32_TYPELESS: return 12;
-    case DXGI_FORMAT_R32G32B32_FLOAT: return 12;
-    case DXGI_FORMAT_R32G32B32_UINT: return 12;
-    case DXGI_FORMAT_R32G32B32_SINT: return 12;
-    case DXGI_FORMAT_R16G16B16A16_TYPELESS: return 8;
-    case DXGI_FORMAT_R16G16B16A16_FLOAT: return 8;
-    case DXGI_FORMAT_R16G16B16A16_UNORM: return 8;
-    case DXGI_FORMAT_R16G16B16A16_UINT: return 8;
-    case DXGI_FORMAT_R16G16B16A16_SNORM: return 8;
-    case DXGI_FORMAT_R16G16B16A16_SINT: return 8;
-    case DXGI_FORMAT_R32G32_TYPELESS: return 8;
-    case DXGI_FORMAT_R32G32_FLOAT: return 8;
-    case DXGI_FORMAT_R32G32_UINT: return 8;
-    case DXGI_FORMAT_R32G32_SINT: return 8;
-    case DXGI_FORMAT_R32G8X24_TYPELESS: return 8;
-    case DXGI_FORMAT_D32_FLOAT_S8X24_UINT: return 4;
-    case DXGI_FORMAT_R32_FLOAT_X8X24_TYPELESS: return 4;
-    case DXGI_FORMAT_X32_TYPELESS_G8X24_UINT: return 4;
-    case DXGI_FORMAT_R10G10B10A2_TYPELESS: return 4;
-    case DXGI_FORMAT_R10G10B10A2_UNORM: return 4;
-    case DXGI_FORMAT_R10G10B10A2_UINT: return 4;
-    case DXGI_FORMAT_R11G11B10_FLOAT: return 4;
-    case DXGI_FORMAT_R8G8B8A8_TYPELESS: return 4;
-    case DXGI_FORMAT_R8G8B8A8_UNORM: return 4;
-    case DXGI_FORMAT_R8G8B8A8_UNORM_SRGB: return 4;
-    case DXGI_FORMAT_R8G8B8A8_UINT: return 4;
-    case DXGI_FORMAT_R8G8B8A8_SNORM: return 4;
-    case DXGI_FORMAT_R8G8B8A8_SINT: return 4;
-    case DXGI_FORMAT_R16G16_TYPELESS: return 4;
-    case DXGI_FORMAT_R16G16_FLOAT: return 4;
-    case DXGI_FORMAT_R16G16_UNORM: return 4;
-    case DXGI_FORMAT_R16G16_UINT: return 4;
-    case DXGI_FORMAT_R16G16_SNORM: return 4;
-    case DXGI_FORMAT_R16G16_SINT: return 4;
-    case DXGI_FORMAT_R32_TYPELESS: return 4;
-    case DXGI_FORMAT_D32_FLOAT: return 4;
-    case DXGI_FORMAT_R32_FLOAT: return 4;
-    case DXGI_FORMAT_R32_UINT: return 4;
-    case DXGI_FORMAT_R32_SINT: return 4;
-    case DXGI_FORMAT_R24G8_TYPELESS: return 4;
-    case DXGI_FORMAT_D24_UNORM_S8_UINT: return 4;
-    case DXGI_FORMAT_R24_UNORM_X8_TYPELESS: return 4;
-    case DXGI_FORMAT_X24_TYPELESS_G8_UINT: return 4;
-    case DXGI_FORMAT_R8G8_TYPELESS: return 2;
-    case DXGI_FORMAT_R8G8_UNORM: return 2;
-    case DXGI_FORMAT_R8G8_UINT: return 2;
-    case DXGI_FORMAT_R8G8_SNORM: return 2;
-    case DXGI_FORMAT_R8G8_SINT: return 2;
-    case DXGI_FORMAT_R16_TYPELESS: return 2;
-    case DXGI_FORMAT_R16_FLOAT: return 2;
-    case DXGI_FORMAT_D16_UNORM: return 2;
-    case DXGI_FORMAT_R16_UNORM: return 2;
-    case DXGI_FORMAT_R16_UINT: return 2;
-    case DXGI_FORMAT_R16_SNORM: return 2;
-    case DXGI_FORMAT_R16_SINT: return 2;
-    case DXGI_FORMAT_R8_TYPELESS: return 1;
-    case DXGI_FORMAT_R8_UNORM: return 1;
-    case DXGI_FORMAT_R8_UINT: return 1;
-    case DXGI_FORMAT_R8_SNORM: return 1;
-    case DXGI_FORMAT_R8_SINT: return 1;
-    case DXGI_FORMAT_A8_UNORM: return 1;
-    case DXGI_FORMAT_R1_UNORM: return 1;
-    default:
-        VERIFY_FAILED(E_INVALIDARG);
-        return 0;
-    }
+  switch (value) {
+  case DXGI_FORMAT_R32G32B32A32_TYPELESS:
+    return 16;
+  case DXGI_FORMAT_R32G32B32A32_FLOAT:
+    return 16;
+  case DXGI_FORMAT_R32G32B32A32_UINT:
+    return 16;
+  case DXGI_FORMAT_R32G32B32A32_SINT:
+    return 16;
+  case DXGI_FORMAT_R32G32B32_TYPELESS:
+    return 12;
+  case DXGI_FORMAT_R32G32B32_FLOAT:
+    return 12;
+  case DXGI_FORMAT_R32G32B32_UINT:
+    return 12;
+  case DXGI_FORMAT_R32G32B32_SINT:
+    return 12;
+  case DXGI_FORMAT_R16G16B16A16_TYPELESS:
+    return 8;
+  case DXGI_FORMAT_R16G16B16A16_FLOAT:
+    return 8;
+  case DXGI_FORMAT_R16G16B16A16_UNORM:
+    return 8;
+  case DXGI_FORMAT_R16G16B16A16_UINT:
+    return 8;
+  case DXGI_FORMAT_R16G16B16A16_SNORM:
+    return 8;
+  case DXGI_FORMAT_R16G16B16A16_SINT:
+    return 8;
+  case DXGI_FORMAT_R32G32_TYPELESS:
+    return 8;
+  case DXGI_FORMAT_R32G32_FLOAT:
+    return 8;
+  case DXGI_FORMAT_R32G32_UINT:
+    return 8;
+  case DXGI_FORMAT_R32G32_SINT:
+    return 8;
+  case DXGI_FORMAT_R32G8X24_TYPELESS:
+    return 8;
+  case DXGI_FORMAT_D32_FLOAT_S8X24_UINT:
+    return 4;
+  case DXGI_FORMAT_R32_FLOAT_X8X24_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_X32_TYPELESS_G8X24_UINT:
+    return 4;
+  case DXGI_FORMAT_R10G10B10A2_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_R10G10B10A2_UNORM:
+    return 4;
+  case DXGI_FORMAT_R10G10B10A2_UINT:
+    return 4;
+  case DXGI_FORMAT_R11G11B10_FLOAT:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_UNORM:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_UNORM_SRGB:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_UINT:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_SNORM:
+    return 4;
+  case DXGI_FORMAT_R8G8B8A8_SINT:
+    return 4;
+  case DXGI_FORMAT_R16G16_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_R16G16_FLOAT:
+    return 4;
+  case DXGI_FORMAT_R16G16_UNORM:
+    return 4;
+  case DXGI_FORMAT_R16G16_UINT:
+    return 4;
+  case DXGI_FORMAT_R16G16_SNORM:
+    return 4;
+  case DXGI_FORMAT_R16G16_SINT:
+    return 4;
+  case DXGI_FORMAT_R32_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_D32_FLOAT:
+    return 4;
+  case DXGI_FORMAT_R32_FLOAT:
+    return 4;
+  case DXGI_FORMAT_R32_UINT:
+    return 4;
+  case DXGI_FORMAT_R32_SINT:
+    return 4;
+  case DXGI_FORMAT_R24G8_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_D24_UNORM_S8_UINT:
+    return 4;
+  case DXGI_FORMAT_R24_UNORM_X8_TYPELESS:
+    return 4;
+  case DXGI_FORMAT_X24_TYPELESS_G8_UINT:
+    return 4;
+  case DXGI_FORMAT_R8G8_TYPELESS:
+    return 2;
+  case DXGI_FORMAT_R8G8_UNORM:
+    return 2;
+  case DXGI_FORMAT_R8G8_UINT:
+    return 2;
+  case DXGI_FORMAT_R8G8_SNORM:
+    return 2;
+  case DXGI_FORMAT_R8G8_SINT:
+    return 2;
+  case DXGI_FORMAT_R16_TYPELESS:
+    return 2;
+  case DXGI_FORMAT_R16_FLOAT:
+    return 2;
+  case DXGI_FORMAT_D16_UNORM:
+    return 2;
+  case DXGI_FORMAT_R16_UNORM:
+    return 2;
+  case DXGI_FORMAT_R16_UINT:
+    return 2;
+  case DXGI_FORMAT_R16_SNORM:
+    return 2;
+  case DXGI_FORMAT_R16_SINT:
+    return 2;
+  case DXGI_FORMAT_R8_TYPELESS:
+    return 1;
+  case DXGI_FORMAT_R8_UNORM:
+    return 1;
+  case DXGI_FORMAT_R8_UINT:
+    return 1;
+  case DXGI_FORMAT_R8_SNORM:
+    return 1;
+  case DXGI_FORMAT_R8_SINT:
+    return 1;
+  case DXGI_FORMAT_A8_UNORM:
+    return 1;
+  case DXGI_FORMAT_R1_UNORM:
+    return 1;
+  default:
+    VERIFY_FAILED(E_INVALIDARG);
+    return 0;
+  }
 }
 #endif
